@@ -118,7 +118,7 @@ tiledb_query_set_buffer <- function(query, attr, buffer) {
       libtiledb_query_set_buffer(query@ptr, attr, buffer)
   } else {              # logical now maps to BOOL which is a uint8_t, we need a different approach
       nr <- NROW(buffer)
-      bufptr <- libtiledb_query_buffer_alloc_ptr("BOOL", nr, FALSE)
+      bufptr <- libtiledb_query_buffer_alloc_ptr("BOOL", nr, FALSE, 1)
       bufptr <- libtiledb_query_buffer_assign_ptr(bufptr, "BOOL", buffer, FALSE)
       query@ptr <- libtiledb_query_set_buffer_ptr(query@ptr, attr, bufptr)
   }
