@@ -11,7 +11,7 @@ hasDataTable <- requireNamespace("data.table", quietly=TRUE)
 hasTibble <- requireNamespace("tibble", quietly=TRUE)
 
 ## GitHub Actions had some jobs killed on the larger data portion so we dial mem use down
-if (Sys.getenv("CI") != "") set_allocation_size_preference(1024*1014)
+if (Sys.getenv("CI") != "") set_allocation_size_preference(1024*1024*5)
 
 #test_that("test tiledb_array read/write sparse array with heterogenous date domains", {
 op <- options()
